@@ -7,7 +7,7 @@ use warnings;
 use autodie;
 use namespace::autoclean;
 
-our $VERSION = '0.69';
+our $VERSION = '0.70';
 
 use Dist::Zilla 6.0;
 
@@ -500,6 +500,17 @@ sub _explicit_prereq_plugins {
                 'Test::Vars'                        => '0.009',
             }
         ],
+
+        # This is solely to work around a bug with Test::Version and
+        # Module::Metadata 1.000019 - see
+        # https://github.com/plicease/Test-Version/issues/7 for details.
+        [
+            'Prereqs' => 'Module::Metadata 1.000033 for Test::Version' => {
+                -phase             => 'develop',
+                -type              => 'requires',
+                'Module::Metadata' => '1.000033',
+            },
+        ],
     );
 }
 
@@ -758,7 +769,7 @@ Dist::Zilla::PluginBundle::DROLSKY - DROLSKY's plugin bundle
 
 =head1 VERSION
 
-version 0.69
+version 0.70
 
 =head1 DESCRIPTION
 
